@@ -1,5 +1,3 @@
-/* $Id: procargs.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
 
@@ -38,7 +36,7 @@ static const unsigned long _glibtop_sysdeps_proc_args =
 /* Init function. */
 
 void
-glibtop_init_proc_args_p (glibtop *server)
+_glibtop_init_proc_args_p (glibtop *server)
 {
 	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
 }
@@ -54,11 +52,6 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 	size_t size = 0, pos = 0;
 	int count;
 
-#ifndef __bsdi__
-	char filename [BUFSIZ];
-	struct stat statb;
-#endif
-
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_args));
@@ -66,25 +59,20 @@ glibtop_get_proc_args_p (glibtop *server, glibtop_proc_args *buf,
 	/* swapper, init, pagedaemon, vmdaemon, update - this doen't work. */
 	if (pid < 5) return NULL;
 
-#ifndef __bsdi__
-	sprintf (filename, "/proc/%d/mem", pid);
-	if (stat (filename, &statb)) return NULL;
-#endif
-
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
 	if ((pinfo == NULL) || (count < 1)) {
-		glibtop_suid_leave (server);
 		glibtop_warn_io_r (server, "kvm_getprocs (%d)", pid);
+		glibtop_suid_leave (server);
 		return NULL;
 	}
 
 	args = kvm_getargv (server->machine.kd, pinfo, max_len);
 	if (args == NULL) {
-		glibtop_suid_leave (server);
 		glibtop_warn_io_r (server, "kvm_getargv (%d)", pid);
+		glibtop_suid_leave (server);
 		return NULL;
 	}
 
