@@ -1,5 +1,3 @@
-/* $Id: uptime.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -34,7 +32,7 @@ static const unsigned long _glibtop_sysdeps_uptime =
 /* Init function. */
 
 void
-glibtop_init_uptime_s (glibtop *server)
+_glibtop_init_uptime_s (glibtop *server)
 {
 	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
